Module decoder

Decoding LogMsg:es from .rrd files/streams.

Modules

stream
streaming

Structs

Decoder

Enums

DecodeError
On failure to encode or serialize a LogMsg.

Functions

decode_bytes
options_from_bytes
read_options
Read encoding options from the beginning of the stream.
read_options_async
Read encoding options from the beginning of the stream asynchronously.