pub struct StreamDecoder { /* private fields */ }Expand description
The stream decoder is a state machine which ingests byte chunks and outputs messages once it has enough data to deserialize one.
Chunks are given to the stream via StreamDecoder::push_chunk,
and messages are read back via StreamDecoder::try_read.
Implementations
Sourceimpl StreamDecoder
impl StreamDecoder