Struct StreamingLogMsg

pub struct StreamingLogMsg {
    pub inner: LogMsg,
    pub byte_offset: u64,
    pub byte_len: u64,
}
A decoded LogMsg with extra contextual information.

Yielded by the StreamingDecoder.

Fields

inner: LogMsg

The decoded LogMsg.

byte_offset: u64

How many bytes does one have to go through in the underlying storage resource in order to find the start of this message?

Specifically, this points to the beginning of the message’s header.

byte_len: u64

How many bytes does this message take in the underlying storage resource?

This covers both the size of the message’s header and its body.

Methods from Deref<Target = LogMsg>

pub fn store_id(&self) -> &StoreId

pub fn set_store_id(&mut self, new_store_id: StoreId)