Module encoder

Encoding of LogMsges as a binary stream, e.g. to store in an .rrd file, or send over network.

Structs

DroppableEncoder
An Encoder that properly closes the stream on drop.
Encoder
Encode a stream of LogMsg into an .rrd file.

Enums

EncodeError
On failure to encode or serialize a LogMsg.

Functions

encode
Returns the size in bytes of the encoded data.
encode_as_bytes
encode_as_bytes_local
encode_ref
Returns the size in bytes of the encoded data.
encode_ref_as_bytes_local
encode_to_bytes
local_encoder
local_raw_encoder