Encoder

Struct Encoder 

pub struct Encoder<W: Write> { /* private fields */ }
Encode a stream of LogMsg into an .rrd file.

When dropped, it will automatically insert an end-of-stream marker, if that wasn’t already done manually.

Implementations

Source

impl Encoder<Vec<u8>>

pub fn local() -> Result<Self, EncodeError>

pub fn encode( messages: impl IntoIterator<Item = ChunkResult<impl Borrow<LogMsg>>>, ) -> Result<Vec<u8>, EncodeError>

All-in-one helper to encode a stream of LogMsgs into an actual RRD stream.

This always uses the local version and its default encoding options.

Returns the encoded data in a newly allocated vector.

Source

impl<W: Write> Encoder<W>

pub fn new_eager( version: CrateVersion, options: EncodingOptions, write: W, ) -> Result<Self, EncodeError>

Creates a new Encoder.

This will immediately write the StreamHeader to the output stream as part of initialization (hence _eager).

There is no _lazy version. Make one if you need one.

pub fn append(&mut self, message: &LogMsg) -> Result<u64, EncodeError>

Returns the size in bytes of the encoded data.

pub fn extend( &mut self, messages: impl IntoIterator<Item = ChunkResult<impl Borrow<LogMsg>>>, ) -> Result<u64, EncodeError>

Returns the size in bytes of the encoded data.

Instructs the encoder to not emit a footer at the end of the stream.

This cannot be reverted.

Returns the span and uncompressed size in bytes of the encoded data.

⚠️ This implies Self::do_not_emit_footer. ⚠️

Safety

message must respect the global settings of the encoder (e.g. the compression used), otherwise the resulting RRD stream will be corrupt and unreadable.

Like Self::finish, but appends the specified, custom RRD footer.

Safety

This is extremely unsafe and only makes sense if you know exactly what you are doing. This is generally only useful when manipulating existing footers and manifests directly, like e.g. rerun rrd route does.

You can verify that the footer you produced is still deserializable using rerun rrd verify.

pub fn finish(&mut self) -> Result<(), EncodeError>

Appends an end-of-stream marker to the encoded bytes. Does not flush.

This is idempotent. This is called automatically on drop.

This end-of-stream marker is currently (seemingly?) relied on for:

  • Tail mode (where the Viewer continuously poll reads from a file on disk).
  • Concatenated RRD file streams (e.g. cat *.rrd | rerun -).
pub fn flush_blocking(&mut self) -> Result<(), EncodeError>

pub fn into_inner(self) -> Result<W, EncodeError>

Source

impl<W: Write> Encoder<W>

pub fn encode_into( version: CrateVersion, options: EncodingOptions, messages: impl IntoIterator<Item = ChunkResult<impl Borrow<LogMsg>>>, write: &mut W, ) -> Result<u64, EncodeError>

All-in-one helper to encode a stream of LogMsgs into an actual RRD stream.

Returns the size in bytes of the encoded data.