pub struct RrdManifestTemporalMapEntry {
pub time_range: AbsoluteTimeRange,
pub num_rows: u64,
}Expand description
The individual entries in an RrdManifestTemporalMap.
Fields
time_range: AbsoluteTimeRangeThe time range covered by this entry.
num_rows: u64The number of rows in the original chunk which are associated with this entry.
At most, this is the same as the number of rows in the chunk as a whole. For a specific entry it might be less, since chunks allow sparse components.