pub struct StreamingLogMsg {
pub kind: MessageKind,
pub version: CrateVersion,
pub encoded: Option<Bytes>,
pub byte_span: Span<u64>,
/* private fields */
}Expand description
A transport-level LogMsg with extra contextual information.
Yielded by the StreamingDecoder.
Fields
kind: MessageKindversion: CrateVersionThe CrateVersion of the RRD stream from which this LogMsg was taken from.
encoded: Option<Bytes>The original Protobuf-encoded bytes of this LogMsg, including headers.
Only set if StreamingDecoderOptions::keep_encoded_protobuf is true.
byte_span: Span<u64>Where in the underlying storage resource is this message (in bytes)?
Specifically, the start of this range points to the beginning of the MessageHeader.
The full range covers both the message’s header and its body.
Implementations
Sourceimpl StreamingLogMsg
impl StreamingLogMsg
Sourcepub fn from_chunk(store_id: StoreId, chunk: &Chunk) -> Result<Self, EncodeError>
pub fn from_chunk(store_id: StoreId, chunk: &Chunk) -> Result<Self, EncodeError>
Create a new StreamingLogMsg from a Chunk.
This is only really useful for testing purposes, and makes no effort at all to be efficient.
Sourcepub fn decoded_transport(&self) -> Result<Option<Msg>, DecodeError>
pub fn decoded_transport(&self) -> Result<Option<Msg>, DecodeError>
Returns the decoded transport-level LogMsg.
This will only decode at the transport-layer (Protobuf), Arrow data is left untouched.
Compute cost:
- If
StreamingDecoderOptions::keep_decoded_protobufwas set on theStreamingDecoderwhen producing theStreamingLogMsg, this is free. - Otherwise, if
StreamingDecoderOptions::keep_encoded_protobufwas set, this has to perform Protobuf decoding. - Otherwise, if neither are set, this just returns
None.